(self.webpackJsonp=self.webpackJsonp||[]).push([[43],{875:function(e,r,n){"use strict";n.r(r),n.d(r,"codeMirror",(function(){return c})),n.d(r,"codeMirrorCss",(function(){return i}));var a=n(475),o=n.n(a),s=n(761),t=(n(762),n(763),n(12));o.a.commands.save=function(e){Object(t.a)(e.getWrapperElement(),"editor-save")};var c=o.a,i=s.a}}]);
//# sourceMappingURL=chunk.9ee74a6c4dec1ab94164.js.map