(self.webpackJsonp=self.webpackJsonp||[]).push([[40],{869:function(e,r,n){"use strict";n.r(r),n.d(r,"codeMirror",(function(){return c})),n.d(r,"codeMirrorCss",(function(){return i}));var s=n(552),o=n.n(s),t=n(755),a=(n(756),n(757),n(12));o.a.commands.save=e=>{Object(a.a)(e.getWrapperElement(),"editor-save")};const c=o.a,i=t.a}}]);
//# sourceMappingURL=chunk.4c7df6324b8077b57d87.js.map